        function getT(rr,cc){
       if(rr==3 && cc==0){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260810 a 12</strong> UTC HH+120 (rango:108-132)<br><strong>control +<br>EPS</strong>';}
       if(rr==3 && cc==1){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260810 a 12</strong> UTC HH+120 (rango:108-132)<br>grupo: <strong>1</strong> representante: <strong>21</strong> miembros: 30 <strong>control</strong><br>0,1,2,4,5,8,9,10,11,13,17,19,21,24,26,27,28,29,32,33,35,39,40,41,42,43,46,47,48,50';}
       if(rr==3 && cc==2){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260810 a 12</strong> UTC HH+120 (rango:108-132)<br>grupo: <strong>2</strong> representante: <strong>23</strong> miembros: 21 <br>3,6,7,12,14,15,16,18,20,22,23,25,30,31,34,36,37,38,44,45,49';}
       if(rr==17 && cc==0){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 1 mm</strong><br><br><strong>20260810 a 12</strong> UTC HH+120 (rango:108-132)<br><strong>control +<br>EPS</strong>';}
       if(rr==17 && cc==1){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 1 mm</strong><br><br><strong>20260810 a 12</strong> UTC HH+120 (rango:108-132)<br>grupo: <strong>1</strong> representante: <strong>21</strong> miembros: 30 <strong>control</strong><br>0,1,2,4,5,8,9,10,11,13,17,19,21,24,26,27,28,29,32,33,35,39,40,41,42,43,46,47,48,50';}
       if(rr==17 && cc==2){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 1 mm</strong><br><br><strong>20260810 a 12</strong> UTC HH+120 (rango:108-132)<br>grupo: <strong>2</strong> representante: <strong>23</strong> miembros: 21 <br>3,6,7,12,14,15,16,18,20,22,23,25,30,31,34,36,37,38,44,45,49';}
       if(rr==19 && cc==0){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 2 mm</strong><br><br><strong>20260810 a 12</strong> UTC HH+120 (rango:108-132)<br><strong>control +<br>EPS</strong>';}
       if(rr==19 && cc==1){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 2 mm</strong><br><br><strong>20260810 a 12</strong> UTC HH+120 (rango:108-132)<br>grupo: <strong>1</strong> representante: <strong>21</strong> miembros: 30 <strong>control</strong><br>0,1,2,4,5,8,9,10,11,13,17,19,21,24,26,27,28,29,32,33,35,39,40,41,42,43,46,47,48,50';}
       if(rr==19 && cc==2){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 2 mm</strong><br><br><strong>20260810 a 12</strong> UTC HH+120 (rango:108-132)<br>grupo: <strong>2</strong> representante: <strong>23</strong> miembros: 21 <br>3,6,7,12,14,15,16,18,20,22,23,25,30,31,34,36,37,38,44,45,49';}
       if(rr==20 && cc==0){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 5 mm</strong><br><br><strong>20260810 a 12</strong> UTC HH+120 (rango:108-132)<br><strong>control +<br>EPS</strong>';}
       if(rr==20 && cc==1){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 5 mm</strong><br><br><strong>20260810 a 12</strong> UTC HH+120 (rango:108-132)<br>grupo: <strong>1</strong> representante: <strong>21</strong> miembros: 30 <strong>control</strong><br>0,1,2,4,5,8,9,10,11,13,17,19,21,24,26,27,28,29,32,33,35,39,40,41,42,43,46,47,48,50';}
       if(rr==20 && cc==2){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 5 mm</strong><br><br><strong>20260810 a 12</strong> UTC HH+120 (rango:108-132)<br>grupo: <strong>2</strong> representante: <strong>23</strong> miembros: 21 <br>3,6,7,12,14,15,16,18,20,22,23,25,30,31,34,36,37,38,44,45,49';}
       if(rr==21 && cc==0){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 10 mm</strong><br><br><strong>20260810 a 12</strong> UTC HH+120 (rango:108-132)<br><strong>control +<br>EPS</strong>';}
       if(rr==21 && cc==1){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 10 mm</strong><br><br><strong>20260810 a 12</strong> UTC HH+120 (rango:108-132)<br>grupo: <strong>1</strong> representante: <strong>21</strong> miembros: 30 <strong>control</strong><br>0,1,2,4,5,8,9,10,11,13,17,19,21,24,26,27,28,29,32,33,35,39,40,41,42,43,46,47,48,50';}
       if(rr==21 && cc==2){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 10 mm</strong><br><br><strong>20260810 a 12</strong> UTC HH+120 (rango:108-132)<br>grupo: <strong>2</strong> representante: <strong>23</strong> miembros: 21 <br>3,6,7,12,14,15,16,18,20,22,23,25,30,31,34,36,37,38,44,45,49';}
       if(rr==22 && cc==0){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 20 mm</strong><br><br><strong>20260810 a 12</strong> UTC HH+120 (rango:108-132)<br><strong>control +<br>EPS</strong>';}
       if(rr==22 && cc==1){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 20 mm</strong><br><br><strong>20260810 a 12</strong> UTC HH+120 (rango:108-132)<br>grupo: <strong>1</strong> representante: <strong>21</strong> miembros: 30 <strong>control</strong><br>0,1,2,4,5,8,9,10,11,13,17,19,21,24,26,27,28,29,32,33,35,39,40,41,42,43,46,47,48,50';}
       if(rr==22 && cc==2){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 20 mm</strong><br><br><strong>20260810 a 12</strong> UTC HH+120 (rango:108-132)<br>grupo: <strong>2</strong> representante: <strong>23</strong> miembros: 21 <br>3,6,7,12,14,15,16,18,20,22,23,25,30,31,34,36,37,38,44,45,49';}
}
